@@ -5,19 +5,14 @@ phi <- function(tab) {
   if (!inherits(tab, "ftable")) tab <- stats::ftable(tab)
 
   tb <- summary(MASS::loglm(~1 + 2, tab))$tests
-  phi_val <- sqrt(tb[2, 1] / sum(tab))
-
-  phi_val
+  sqrt(tb[2, 1] / sum(tab))
 }
 
 
 #' @rdname xtab_statistics
 #' @export
 cramer <- function(tab) {
+  # convert to flat table
   if (!inherits(tab, "ftable")) tab <- stats::ftable(tab)
-
-  phi_val <- phi(tab)
-  cramer <- sqrt(phi_val ^ 2 / min(dim(tab) - 1))
-
-  cramer
+  sqrt(phi(tab) ^ 2 / min(dim(tab) - 1))
 }
